#ifndef NT2_INCLUDE_FUNCTIONS_HILB_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_HILB_HPP_INCLUDED

#include <nt2/gallery/include/functions/hilb.hpp>

#endif
